@@ -124,6 +124,8 @@ class BaseDialect(AbstractDialect):
     SUPPORTS_INDEXES = False
     TYPE_CLASSES: Dict[str, type] = {}
 
+    PLACEHOLDER_TABLE = None        # Used for Oracle
+
     def offset_limit(self, offset: Optional[int] = None, limit: Optional[int] = None):
         if offset:
             raise NotImplementedError("No support for OFFSET in query")
@@ -302,7 +304,9 @@ class Database(AbstractDatabase):
             return int(res)
         elif res_type is datetime:
             res = _one(_one(res))
-            return res  # XXX parse timestamp?
+            if isinstance(res, str):
+                res = datetime.fromisoformat(res[:23])  # TODO use a better parsing method
+            return res
         elif res_type is tuple:
             assert len(res) == 1, (sql_code, res)
             return res[0]
