@@ -144,6 +144,9 @@ class Dialect(BaseDialect, Mixin_Schema):
     def set_timezone_to_utc(self) -> str:
         return "SET TIME ZONE TO 'UTC'"
 
+    def current_timestamp(self) -> str:
+        return "current_timestamp(6)"
+
 
 class Vertica(ThreadedDatabase):
     dialect = Dialect()
